Struct aws_sdk_codeartifact::client::Client [−][src]
pub struct Client<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
An ergonomic service client for CodeArtifactControlPlaneService.
This client allows ergonomic access to a CodeArtifactControlPlaneService-shaped service.
Each method corresponds to an endpoint defined in the service’s Smithy model,
and the request and response shapes are auto-generated from that same model.
Using a Client
Once you have a client set up, you can access the service’s endpoints
by calling the appropriate method on Client. Each such method
returns a request builder for that endpoint, with methods for setting
the various fields of the request. Once your request is complete, use
the send method to send the request. send returns a future, which
you then have to .await to get the service’s response.
Implementations
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
Constructs a fluent builder for the AssociateExternalConnection operation.
See AssociateExternalConnection for more information about the
operation and its arguments.
Constructs a fluent builder for the CopyPackageVersions operation.
See CopyPackageVersions for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateDomain operation.
See CreateDomain for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateRepository operation.
See CreateRepository for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteDomain operation.
See DeleteDomain for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteDomainPermissionsPolicy operation.
See DeleteDomainPermissionsPolicy for more information about the
operation and its arguments.
Constructs a fluent builder for the DeletePackageVersions operation.
See DeletePackageVersions for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteRepository operation.
See DeleteRepository for more information about the
operation and its arguments.
pub fn delete_repository_permissions_policy(
&self
) -> DeleteRepositoryPermissionsPolicy<C, M, R>
pub fn delete_repository_permissions_policy(
&self
) -> DeleteRepositoryPermissionsPolicy<C, M, R>
Constructs a fluent builder for the DeleteRepositoryPermissionsPolicy operation.
See DeleteRepositoryPermissionsPolicy for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeDomain operation.
See DescribeDomain for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribePackageVersion operation.
See DescribePackageVersion for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeRepository operation.
See DescribeRepository for more information about the
operation and its arguments.
Constructs a fluent builder for the DisassociateExternalConnection operation.
See DisassociateExternalConnection for more information about the
operation and its arguments.
Constructs a fluent builder for the DisposePackageVersions operation.
See DisposePackageVersions for more information about the
operation and its arguments.
Constructs a fluent builder for the GetAuthorizationToken operation.
See GetAuthorizationToken for more information about the
operation and its arguments.
Constructs a fluent builder for the GetDomainPermissionsPolicy operation.
See GetDomainPermissionsPolicy for more information about the
operation and its arguments.
Constructs a fluent builder for the GetPackageVersionAsset operation.
See GetPackageVersionAsset for more information about the
operation and its arguments.
Constructs a fluent builder for the GetPackageVersionReadme operation.
See GetPackageVersionReadme for more information about the
operation and its arguments.
Constructs a fluent builder for the GetRepositoryEndpoint operation.
See GetRepositoryEndpoint for more information about the
operation and its arguments.
Constructs a fluent builder for the GetRepositoryPermissionsPolicy operation.
See GetRepositoryPermissionsPolicy for more information about the
operation and its arguments.
Constructs a fluent builder for the ListDomains operation.
See ListDomains for more information about the
operation and its arguments.
Constructs a fluent builder for the ListPackages operation.
See ListPackages for more information about the
operation and its arguments.
Constructs a fluent builder for the ListPackageVersionAssets operation.
See ListPackageVersionAssets for more information about the
operation and its arguments.
Constructs a fluent builder for the ListPackageVersionDependencies operation.
See ListPackageVersionDependencies for more information about the
operation and its arguments.
Constructs a fluent builder for the ListPackageVersions operation.
See ListPackageVersions for more information about the
operation and its arguments.
Constructs a fluent builder for the ListRepositories operation.
See ListRepositories for more information about the
operation and its arguments.
Constructs a fluent builder for the ListRepositoriesInDomain operation.
See ListRepositoriesInDomain for more information about the
operation and its arguments.
Constructs a fluent builder for the ListTagsForResource operation.
See ListTagsForResource for more information about the
operation and its arguments.
Constructs a fluent builder for the PutDomainPermissionsPolicy operation.
See PutDomainPermissionsPolicy for more information about the
operation and its arguments.
Constructs a fluent builder for the PutRepositoryPermissionsPolicy operation.
See PutRepositoryPermissionsPolicy for more information about the
operation and its arguments.
Constructs a fluent builder for the TagResource operation.
See TagResource for more information about the
operation and its arguments.
Constructs a fluent builder for the UntagResource operation.
See UntagResource for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdatePackageVersionsStatus operation.
See UpdatePackageVersionsStatus for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateRepository operation.
See UpdateRepository for more information about the
operation and its arguments.
Creates a client with the given service config and connector override.